@@ -230,15 +230,38 @@ axis.default <-
                    right = ,
                    top = scales$tck[2])
         if (!is.logical(comp.list)) ## must be FALSE if it is
-            panel.axis(side = side,
-                       at = comp.list$ticks$at,
-                       labels = comp.list$labels$labels,
-                       draw.labels = do.labels, 
-                       check.overlap = comp.list$labels$check.overlap,
-                       outside = TRUE,
-                       ticks = do.ticks,
-                       tck = scales.tck * comp.list$ticks$tck,
-                       ...)
+        {
+            ## WAS: (but did not allow ticks$at and labels$at to be different)
+            ## panel.axis(side = side,
+            ##            at = comp.list$ticks$at,
+            ##            labels = comp.list$labels$labels,
+            ##            draw.labels = do.labels, 
+            ##            check.overlap = comp.list$labels$check.overlap,
+            ##            outside = TRUE,
+            ##            ticks = do.ticks,
+            ##            tck = scales.tck * comp.list$ticks$tck,
+            ##            ...)
+            if (do.ticks)
+                panel.axis(side = side,
+                           at = comp.list$ticks$at,
+                           labels = FALSE,
+                           draw.labels = FALSE, 
+                           check.overlap = FALSE,
+                           outside = TRUE,
+                           ticks = TRUE,
+                           tck = scales.tck * comp.list$ticks$tck,
+                           ...)
+            if (do.labels)
+                panel.axis(side = side,
+                           at = comp.list$labels$at,
+                           labels = comp.list$labels$labels,
+                           draw.labels = TRUE, 
+                           check.overlap = comp.list$labels$check.overlap,
+                           outside = TRUE,
+                           ticks = FALSE,
+                           tck = scales.tck * comp.list$ticks$tck,
+                           ...)
+        }
     }
 }
 
@@ -352,13 +375,14 @@ formattedTicksAndLabels.default <-
     {
         at <- checkArgsAndCall(pretty, list(x = x[is.finite(x)], ...))
     }
-    else if (have.log)  ## and at specified
+    else if (have.log && (length(at) > 0))  ## 'at' specified but not NULL
     {
         if (is.logical(labels)) labels <- as.character(at)
         at <- log(at, base = logbase)
     }
-    list(at = at, labels = if (is.logical(labels))
-         paste(logpaste, format(at, trim = TRUE), sep = "") else labels,
+    list(at = at,
+         labels = if (is.logical(labels)) paste(logpaste, format(at, trim = TRUE), sep = "")
+                  else labels,
          check.overlap = check.overlap,
          num.limit = rng)
 }
@@ -397,7 +421,7 @@ formattedTicksAndLabels.date <-
         class(at) <- "date"
         datelabels <- as.character(at)
     }
-    else if (have.log) ## and at specified
+    else if (have.log && (length(at) > 0))
     {
         if (is.logical(labels)) labels <- as.character(at)
         at <- log(at, base = logbase)
@@ -426,12 +450,23 @@ formattedTicksAndLabels.character <-
               format.posixt = NULL)
 {
     retain <- if (is.null(used.at) || any(is.na(used.at))) TRUE else used.at
-    ans <- list(at = if (is.logical(at)) seq_along(x)[retain] else at,
-                labels = if (is.logical(labels)) x[retain] else labels,
-                check.overlap = FALSE)
-    ans$num.limit <- c(-1, 1) * lattice.getOption("axis.padding")$factor + 
-        if (is.null(num.limit) || any(is.na(num.limit))) range(ans$at)
-        else num.limit
+    ## OLD: ans <- list(at = if (is.logical(at)) seq_along(x)[retain] else at,
+    ##             labels = if (is.logical(labels)) x[retain] else labels,
+    ##             check.overlap = FALSE)
+    ans <- list()
+    ans$at <- if (is.logical(at)) seq_along(x)[retain] else at
+    ans$labels <- if (is.logical(labels)) {
+        if (all(ans$at %in% seq_along(x)))
+            x[ans$at]
+        else ## meaningless at, since not corresponding to values
+            as.character(ans$at) # best guess
+    } else labels
+    ans$check.overlap <- FALSE
+    ans$num.limit <-
+        c(-1, 1) * lattice.getOption("axis.padding")$factor + 
+            if (is.null(num.limit) || any(is.na(num.limit)))
+                c(1, length(x)) ## WAS range(ans$at), not sure why
+            else num.limit
     ans
 }
 
@@ -448,11 +483,17 @@ formattedTicksAndLabels.expression <-
              format.posixt = NULL)
 {
     retain <- if (is.null(used.at) || any(is.na(used.at))) TRUE else used.at
-    ans <- list(at = if (is.logical(at)) seq_along(x)[retain] else at,
-                labels = if (is.logical(labels)) x[retain] else labels,
-                check.overlap = FALSE)
+    ans <- list()
+    ans$at <- if (is.logical(at)) seq_along(x)[retain] else at
+    ans$labels <- if (is.logical(labels)) {
+        if (all(ans$at %in% seq_along(x)))
+            x[ans$at]
+        else ## meaningless at, since not corresponding to values
+            as.character(ans$at) # best guess
+    } else labels
     ans$num.limit <- c(-1, 1) * lattice.getOption("axis.padding")$factor + 
-        if (is.null(num.limit) || any(is.na(num.limit))) range(ans$at)
+        if (is.null(num.limit) || any(is.na(num.limit))) ## range(ans$at)
+            c(1, length(x))
         else num.limit
     ans
 }
@@ -896,31 +937,39 @@ panel.axis <-
         else unit(x = axis.settings$pad1 * axis.units$pad1$x, units = axis.units$pad1$units)
     orient.factor <- if (outside) -1 else 1
 
-    if (any(tck.unit.x != 0))
+    if (ticks && any(tck.unit.x != 0))
         switch(side, 
                bottom = 
                grid.segments(x0 = unit(at[axid], "native"),
                              x1 = unit(at[axid], "native"),
                              y0 = unit(0, "npc"),
                              y1 = orient.factor * tck.unit,
+                             name = trellis.grobname("ticks.bottom",
+                               type="panel"),
                              gp = gp.line),
                top = 
                grid.segments(x0 = unit(at[axid], "native"),
                              x1 = unit(at[axid], "native"),
                              y0 = unit(1, "npc"),
                              y1 = unit(1, "npc") - orient.factor * tck.unit,
+                             name = trellis.grobname("ticks.top",
+                               type="panel"),
                              gp = gp.line),
                left = 
                grid.segments(y0 = unit(at[axid], "native"),
                              y1 = unit(at[axid], "native"),
                              x0 = unit(0, "npc"),
                              x1 = orient.factor * tck.unit,
+                             name = trellis.grobname("ticks.left",
+                               type="panel"),
                              gp = gp.line),
                right =
                grid.segments(y0 = unit(at[axid], "native"),
                              y1 = unit(at[axid], "native"),
                              x0 = unit(1, "npc"),
                              x1 = unit(1, "npc") - orient.factor * tck.unit,
+                             name = trellis.grobname("ticks.right",
+                               type="panel"),
                              gp = gp.line))
 
     if (draw.labels && !is.null(labels))
@@ -949,6 +998,8 @@ panel.axis <-
                          rot = rot[1],
                          check.overlap = check.overlap,
                          just = just,
+                         name = trellis.grobname("ticklabels.bottom",
+                           type="panel"),
                          gp = gp.text),
                top =
                grid.text(label = labels[axid & keep.labels],
@@ -957,6 +1008,8 @@ panel.axis <-
                          rot = rot[1],
                          check.overlap = check.overlap,
                          just = just,
+                         name = trellis.grobname("ticklabels.top",
+                           type="panel"),
                          gp = gp.text),
                left =
                grid.text(label = labels[axid & keep.labels],
@@ -965,6 +1018,8 @@ panel.axis <-
                          rot = rot[2],
                          check.overlap = check.overlap,
                          just = just,
+                         name = trellis.grobname("ticklabels.left",
+                           type="panel"),
                          gp = gp.text),
                right =
                grid.text(label = labels[axid & keep.labels],
@@ -973,6 +1028,8 @@ panel.axis <-
                          rot = rot[2],
                          check.overlap = check.overlap,
                          just = just,
+                         name = trellis.grobname("ticklabels.right",
+                           type="panel"),
                          gp = gp.text))
     }
     invisible()
